@@ -180,6 +180,24 @@ more efficient passing mechanism for large numbers of values.
                   +{};
                 }
               }
+            } elsif ( @_ == 2 and ref $_[1] eq 'HASH') {
+              %%STORE(+{%{$_[1]}},$v)%%
+              # Only asgn-check the potential *values*
+              %%ASGNCHK%(%%IFSTORE(values %$v, values %{$_[1]})%%)%%
+              if ( ! defined $want ) {
+                %{%%STORAGE%%} = %%IFSTORE(%$v,%{$_[1]})%%;
+                return;
+              }
+  
+              if ( $want ) {
+                (%{%%STORAGE%%} = %%IFSTORE(%$v,%{$_[1]})%%);
+              } else {
+                +{%{%%STORAGE%%} = %%IFSTORE(%$v,%{$_[1]})%%}; %%V2ONLY%%
+                %%V1COMPAT_ON%%
+                %{%%STORAGE%%} = %%IFSTORE(%$v,%{$_[1]})%%;
+                %%STORAGE%%;
+                %%V1COMPAT_OFF%%
+              }
             } else {
               croak "Uneven number of arguments to method '$names{'*'}'\n"
                 unless @_ % 2;
